@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone 
+ * This file is part of Liblinphone
  * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -37,14 +37,14 @@ extern "C" {
  * @param cbs #LinphoneImEncryptionEngineCbs object.
  * @return The same #LinphoneImEncryptionEngineCbs object.
  * @donotwrap
-**/
-LinphoneImEncryptionEngineCbs * linphone_im_encryption_engine_cbs_ref(LinphoneImEncryptionEngineCbs *cbs);
+ **/
+LinphoneImEncryptionEngineCbs *linphone_im_encryption_engine_cbs_ref(LinphoneImEncryptionEngineCbs *cbs);
 
 /**
  * Release reference to the LinphoneImEncryptionEngineCbs.
  * @param cbs #LinphoneImEncryptionEngineCbs object.
  * @donotwrap
-**/
+ **/
 void linphone_im_encryption_engine_cbs_unref(LinphoneImEncryptionEngineCbs *cbs);
 
 /**
@@ -52,7 +52,7 @@ void linphone_im_encryption_engine_cbs_unref(LinphoneImEncryptionEngineCbs *cbs)
  * @param cbs the #LinphoneImEncryptionEngineCbs
  * @return the user data
  * @donotwrap
-*/
+ */
 LINPHONE_PUBLIC void *linphone_im_encryption_engine_cbs_get_user_data(const LinphoneImEncryptionEngineCbs *cbs);
 
 /**
@@ -60,7 +60,7 @@ LINPHONE_PUBLIC void *linphone_im_encryption_engine_cbs_get_user_data(const Linp
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @param data the user data
  * @donotwrap
-*/
+ */
 LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_user_data(LinphoneImEncryptionEngineCbs *cbs, void *data);
 
 /**
@@ -68,14 +68,14 @@ LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_user_data(LinphoneImE
  * @param imee #LinphoneImEncryptionEngine object.
  * @return The same #LinphoneImEncryptionEngine object.
  * @donotwrap
-**/
-LINPHONE_PUBLIC LinphoneImEncryptionEngine * linphone_im_encryption_engine_ref(LinphoneImEncryptionEngine *imee);
+ **/
+LINPHONE_PUBLIC LinphoneImEncryptionEngine *linphone_im_encryption_engine_ref(LinphoneImEncryptionEngine *imee);
 
 /**
  * Release reference to the LinphoneImEncryptionEngine.
  * @param imee #LinphoneImEncryptionEngine object.
  * @donotwrap
-**/
+ **/
 LINPHONE_PUBLIC void linphone_im_encryption_engine_unref(LinphoneImEncryptionEngine *imee);
 
 /**
@@ -83,7 +83,7 @@ LINPHONE_PUBLIC void linphone_im_encryption_engine_unref(LinphoneImEncryptionEng
  * @param imee the #LinphoneImEncryptionEngine
  * @return the user data
  * @donotwrap
-*/
+ */
 LINPHONE_PUBLIC void *linphone_im_encryption_engine_get_user_data(const LinphoneImEncryptionEngine *imee);
 
 /**
@@ -91,7 +91,7 @@ LINPHONE_PUBLIC void *linphone_im_encryption_engine_get_user_data(const Linphone
  * @param imee the #LinphoneImEncryptionEngine object
  * @param data the user data
  * @donotwrap
-*/
+ */
 LINPHONE_PUBLIC void linphone_im_encryption_engine_set_user_data(LinphoneImEncryptionEngine *imee, void *data);
 
 /**
@@ -100,119 +100,136 @@ LINPHONE_PUBLIC void linphone_im_encryption_engine_set_user_data(LinphoneImEncry
  * @return The #LinphoneCore object that created the IM encryption engine
  * @donotwrap
  */
-LINPHONE_PUBLIC LinphoneCore * linphone_im_encryption_engine_get_core(LinphoneImEncryptionEngine *imee);
+LINPHONE_PUBLIC LinphoneCore *linphone_im_encryption_engine_get_core(LinphoneImEncryptionEngine *imee);
 
 /**
  * Gets the #LinphoneImEncryptionEngineCbs object that holds the callbacks
  * @param imee the #LinphoneImEncryptionEngine object
  * @return the #LinphoneImEncryptionEngineCbs object
  * @donotwrap
-*/
-LINPHONE_PUBLIC LinphoneImEncryptionEngineCbs* linphone_im_encryption_engine_get_callbacks(const LinphoneImEncryptionEngine *imee);
+ */
+LINPHONE_PUBLIC LinphoneImEncryptionEngineCbs *
+linphone_im_encryption_engine_get_callbacks(const LinphoneImEncryptionEngine *imee);
 
 /**
  * Gets the callback that will decrypt the chat messages upon reception
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @return the callback
  * @donotwrap
-*/
-LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsIncomingMessageCb linphone_im_encryption_engine_cbs_get_process_incoming_message(LinphoneImEncryptionEngineCbs *cbs);
+ */
+LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsIncomingMessageCb
+linphone_im_encryption_engine_cbs_get_process_incoming_message(LinphoneImEncryptionEngineCbs *cbs);
 
 /**
  * Sets the callback that will decrypt the chat messages upon reception
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @param cb the callback to call
  * @donotwrap
-*/
-LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_process_incoming_message(LinphoneImEncryptionEngineCbs *cbs, LinphoneImEncryptionEngineCbsIncomingMessageCb cb);
+ */
+LINPHONE_PUBLIC void
+linphone_im_encryption_engine_cbs_set_process_incoming_message(LinphoneImEncryptionEngineCbs *cbs,
+                                                               LinphoneImEncryptionEngineCbsIncomingMessageCb cb);
 
 /**
  * Gets the callback that will encrypt the chat messages before sending them
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @return the callback
  * @donotwrap
-*/
-LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsOutgoingMessageCb linphone_im_encryption_engine_cbs_get_process_outgoing_message(LinphoneImEncryptionEngineCbs *cbs);
+ */
+LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsOutgoingMessageCb
+linphone_im_encryption_engine_cbs_get_process_outgoing_message(LinphoneImEncryptionEngineCbs *cbs);
 
 /**
  * Sets the callback that will encrypt the chat messages before sending them
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @param cb the callback to call
  * @donotwrap
-*/
-LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_process_outgoing_message(LinphoneImEncryptionEngineCbs *cbs, LinphoneImEncryptionEngineCbsOutgoingMessageCb cb);
+ */
+LINPHONE_PUBLIC void
+linphone_im_encryption_engine_cbs_set_process_outgoing_message(LinphoneImEncryptionEngineCbs *cbs,
+                                                               LinphoneImEncryptionEngineCbsOutgoingMessageCb cb);
 
 /**
  * Gets the callback that will decrypt the files while downloading them
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @return the callback
  * @donotwrap
-*/
-LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsDownloadingFileCb linphone_im_encryption_engine_cbs_get_process_downloading_file(LinphoneImEncryptionEngineCbs *cbs);
+ */
+LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsDownloadingFileCb
+linphone_im_encryption_engine_cbs_get_process_downloading_file(LinphoneImEncryptionEngineCbs *cbs);
 
 /**
  * Sets the callback that will decrypt the files while downloading them
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @param cb the callback to call
  * @donotwrap
-*/
-LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_process_downloading_file(LinphoneImEncryptionEngineCbs *cbs, LinphoneImEncryptionEngineCbsDownloadingFileCb cb);
+ */
+LINPHONE_PUBLIC void
+linphone_im_encryption_engine_cbs_set_process_downloading_file(LinphoneImEncryptionEngineCbs *cbs,
+                                                               LinphoneImEncryptionEngineCbsDownloadingFileCb cb);
 
 /**
  * Gets the callback that will will encrypt the files while uploading them
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @return the callback
  * @donotwrap
-*/
-LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsUploadingFileCb linphone_im_encryption_engine_cbs_get_process_uploading_file(LinphoneImEncryptionEngineCbs *cbs);
+ */
+LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsUploadingFileCb
+linphone_im_encryption_engine_cbs_get_process_uploading_file(LinphoneImEncryptionEngineCbs *cbs);
 
 /**
  * Sets the callback that will encrypt the files while uploading them
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @param cb the callback to call
  * @donotwrap
-*/
-LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_process_uploading_file(LinphoneImEncryptionEngineCbs *cbs, LinphoneImEncryptionEngineCbsUploadingFileCb cb);
+ */
+LINPHONE_PUBLIC void
+linphone_im_encryption_engine_cbs_set_process_uploading_file(LinphoneImEncryptionEngineCbs *cbs,
+                                                             LinphoneImEncryptionEngineCbsUploadingFileCb cb);
 
 /**
  * Gets the callback telling whether or not to encrypt the files
  * @param cbs the LinphoneImEncryptionEngineCbs object
  * @return the callback
  * @donotwrap
-*/
-LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsIsEncryptionEnabledForFileTransferCb linphone_im_encryption_engine_cbs_get_is_encryption_enabled_for_file_transfer(LinphoneImEncryptionEngineCbs *cbs);
+ */
+LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsIsEncryptionEnabledForFileTransferCb
+linphone_im_encryption_engine_cbs_get_is_encryption_enabled_for_file_transfer(LinphoneImEncryptionEngineCbs *cbs);
 
 /**
  * Sets the callback telling whether or not to encrypt the files
  * @param cbs the LinphoneImEncryptionEngineCbs object
  * @param cb the callback to call
  * @donotwrap
-*/
-LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_is_encryption_enabled_for_file_transfer(LinphoneImEncryptionEngineCbs *cbs, LinphoneImEncryptionEngineCbsIsEncryptionEnabledForFileTransferCb cb);
+ */
+LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_is_encryption_enabled_for_file_transfer(
+    LinphoneImEncryptionEngineCbs *cbs, LinphoneImEncryptionEngineCbsIsEncryptionEnabledForFileTransferCb cb);
 
 /**
  * Gets the callback that will generate the key to encrypt the file before uploading it
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @return the callback
  * @donotwrap
-*/
-LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsGenerateFileTransferKeyCb linphone_im_encryption_engine_cbs_get_generate_file_transfer_key(LinphoneImEncryptionEngineCbs *cbs);
+ */
+LINPHONE_PUBLIC LinphoneImEncryptionEngineCbsGenerateFileTransferKeyCb
+linphone_im_encryption_engine_cbs_get_generate_file_transfer_key(LinphoneImEncryptionEngineCbs *cbs);
 
 /**
  * Sets the callback that will generate the key to encrypt the file before uploading it
  * @param cbs the #LinphoneImEncryptionEngineCbs object
  * @param cb the callback to call
  * @donotwrap
-*/
-LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_generate_file_transfer_key(LinphoneImEncryptionEngineCbs *cbs, LinphoneImEncryptionEngineCbsGenerateFileTransferKeyCb cb);
+ */
+LINPHONE_PUBLIC void linphone_im_encryption_engine_cbs_set_generate_file_transfer_key(
+    LinphoneImEncryptionEngineCbs *cbs, LinphoneImEncryptionEngineCbsGenerateFileTransferKeyCb cb);
 
 /**
  * Create the IM encryption engine
  * @return The created the IM encryption engine
  * @donotwrap
-*/
+ */
 LINPHONE_PUBLIC LinphoneImEncryptionEngine *linphone_im_encryption_engine_new(void);
-	
+
 /**
  * @}
  */
