@@ -148,7 +148,7 @@ LINPHONE_PUBLIC LinphoneStatus linphone_config_load_from_xml_string(LinphoneConf
 /**
  * Returns the filename used to store the user config.
  * @ingroup misc
- * @param config the #LinphoneConfig object. @notnill
+ * @param config the #LinphoneConfig object. @notnil
  * @return the filename used to store the user config if any. @maybenil
  * @donotwrap
  */
@@ -157,7 +157,7 @@ LINPHONE_PUBLIC const char *linphone_config_get_filename(const LinphoneConfig *c
 /**
  * Returns the filename that was used as the factory config.
  * @ingroup misc
- * @param config the #LinphoneConfig object. @notnill
+ * @param config the #LinphoneConfig object. @notnil
  * @return the filename used to as the factory config if any. @maybenil
  * @donotwrap
  */
@@ -166,7 +166,7 @@ LINPHONE_PUBLIC const char *linphone_config_get_factory_filename(const LinphoneC
 /**
  * Returns the temporary filename used to store the user config.
  * @ingroup misc
- * @param config the #LinphoneConfig object. @notnill
+ * @param config the #LinphoneConfig object. @notnil
  * @return the temporary filename used to store the user config if any. @maybenil
  * @donotwrap
  */
@@ -667,6 +667,14 @@ LINPHONE_PUBLIC LinphoneDictionary *linphone_config_section_to_dict(const Linpho
 LINPHONE_PUBLIC void
 linphone_config_load_dict_to_section(LinphoneConfig *config, const char *section, const LinphoneDictionary *dict);
 
+/**
+ * Indicates whether the LinphoneConfig object is readonly, in other words
+ * it has no file backend or file is opened without write permission.
+ * @param config the #LinphoneConfig object @notnil
+ * @return a boolean.
+ */
+LINPHONE_PUBLIC bool_t linphone_config_is_readonly(const LpConfig *config);
+
 /************ */
 /* DEPRECATED */
 /* ********** */
