@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone 
+ * This file is part of Liblinphone
  * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -175,14 +175,16 @@ LINPHONE_PUBLIC bctbx_list_t *linphone_vcard_get_phone_numbers(const LinphoneVca
  * @param vCard the #LinphoneVcard @notnil
  * @param phoneNumber the #LinphoneFriendPhoneNumber to add @notnil
  */
-LINPHONE_PUBLIC void linphone_vcard_add_phone_number_with_label(LinphoneVcard *vCard, LinphoneFriendPhoneNumber *phoneNumber);
+LINPHONE_PUBLIC void linphone_vcard_add_phone_number_with_label(LinphoneVcard *vCard,
+                                                                LinphoneFriendPhoneNumber *phoneNumber);
 
 /**
  * Removes a #LinphoneFriendPhoneNumber in the vCard (if it exists), using the TEL property
  * @param vCard the #LinphoneVcard @notnil
  * @param phoneNumber the #LinphoneFriendPhoneNumber to remove @notnil
  */
-LINPHONE_PUBLIC void linphone_vcard_remove_phone_number_with_label(LinphoneVcard *vCard, const LinphoneFriendPhoneNumber *phoneNumber);
+LINPHONE_PUBLIC void linphone_vcard_remove_phone_number_with_label(LinphoneVcard *vCard,
+                                                                   const LinphoneFriendPhoneNumber *phoneNumber);
 
 /**
  * Returns the list of phone numbers in the vCard (all the TEL attributes) or NULL
@@ -211,10 +213,31 @@ LINPHONE_PUBLIC const char *linphone_vcard_get_organization(const LinphoneVcard
  */
 LINPHONE_PUBLIC void linphone_vcard_remove_organization(LinphoneVcard *vCard);
 
+/**
+ * Fills the Title field of the vCard
+ * @param vCard the #LinphoneVcard @notnil
+ * @param job_title the job title. @maybenil
+ */
+LINPHONE_PUBLIC void linphone_vcard_set_job_title(LinphoneVcard *vCard, const char *job_title);
+
+/**
+ * Gets the Title of the vCard
+ * @param vCard the #LinphoneVcard @notnil
+ * @return the Title of the vCard or NULL. @maybenil
+ */
+LINPHONE_PUBLIC const char *linphone_vcard_get_job_title(const LinphoneVcard *vCard);
+
+/**
+ * Removes the Title field of the vCard
+ * @param vCard the #LinphoneVcard @notnil
+ */
+LINPHONE_PUBLIC void linphone_vcard_remove_job_title(LinphoneVcard *vCard);
+
 /**
  * Sets a picture URI in the vCard, using the PHOTO property
  * @param vCard the #LinphoneVcard @notnil
- * @param picture the picture URI to add. If NULL it will have the same effet as linphone_vcard_remove_photo(). @maybenil
+ * @param picture the picture URI to add. If NULL it will have the same effet as linphone_vcard_remove_photo().
+ * @maybenil
  */
 LINPHONE_PUBLIC void linphone_vcard_set_photo(LinphoneVcard *vCard, const char *picture);
 
@@ -288,7 +311,7 @@ LINPHONE_PUBLIC const char *linphone_vcard_get_url(const LinphoneVcard *vCard);
  * @return The extended properties values as string. \bctbx_list{char *} @maybenil @tobefreed
  */
 LINPHONE_PUBLIC bctbx_list_t *linphone_vcard_get_extended_properties_values_by_name(const LinphoneVcard *vCard,
-																					const char *name);
+                                                                                    const char *name);
 
 /**
  * Adds an extended property to the vCard
